#
# spec file for package plexus-archiver
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-archiver
Version:        4.10.0
Release:        3.1
Summary:        Plexus Archiver Component
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://codehaus-plexus.github.io/plexus-archiver
Source0:        https://github.com/codehaus-plexus/plexus-archiver/archive/plexus-archiver-%{version}.tar.gz
Source1:        %{name}-build.xml
Patch0:         0001-Remove-support-for-snappy.patch
Patch1:         0002-Remove-support-for-zstd.patch
Patch2:         y2038.patch
BuildRequires:  ant
BuildRequires:  apache-commons-compress
BuildRequires:  apache-commons-io
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  jsr-305
BuildRequires:  objectweb-asm
BuildRequires:  plexus-io >= 3.2
BuildRequires:  plexus-utils >= 3.3
BuildRequires:  sisu-inject
BuildRequires:  slf4j
BuildRequires:  xz-java
BuildArch:      noarch

%description
Plexus contains end-to-end developer tools for writing applications.
At the core is the container, which can be embedded or for an
application server. There are many reusable components for hibernate,
form processing, jndi, i18n, velocity, etc. Plexus also includes an
application server which is like a J2EE application server.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}
cp %{SOURCE1} build.xml

%patch -P 0 -p1
%pom_remove_dep io.airlift:aircompressor
rm -rf src/main/java/org/codehaus/plexus/archiver/snappy
rm -rf src/test/java/org/codehaus/plexus/archiver/snappy
rm -f src/main/java/org/codehaus/plexus/archiver/tar/SnappyTarFile.java
rm -f src/main/java/org/codehaus/plexus/archiver/tar/PlexusIoTarSnappyFileResourceCollection.java
rm -r src/test/java/org/codehaus/plexus/archiver/tar/TarSnappyUnArchiverTest.java

%patch -P 1 -p1
%pom_remove_dep com.github.luben:zstd-jni
rm -rf src/main/java/org/codehaus/plexus/archiver/zstd
rm -rf src/test/java/org/codehaus/plexus/archiver/zstd
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/PlexusIoTZstdFileResourceCollection.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/ZstdTarFile.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/TZstdUnArchiver.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/TZstdArchiver.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/TarZstdUnArchiver.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/PlexusIoTarZstdFileResourceCollection.java
rm -rf src/main/java/org/codehaus/plexus/archiver/tar/TarZstdArchiver.java
rm -rf src/test/java/org/codehaus/plexus/archiver/tar/TarZstdUnArchiverTest.java

%patch -P 2 -p1

%build
mkdir -p lib
build-jar-repository -s lib \
    atinject \
    commons-compress \
    commons-io \
    jsr-305 \
    objectweb-asm/asm \
    org.eclipse.sisu.inject \
    plexus/io \
    plexus/utils \
    slf4j/api
%{ant} \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/plexus
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/plexus/archiver.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/plexus
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/plexus/archiver.pom
%add_maven_depmap plexus/archiver.pom plexus/archiver.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE

%files javadoc
%license LICENSE
%{_javadocdir}/%{name}

%changelog
* Tue Jun  3 2025 Fridrich Strba <fstrba@suse.com>
- Add dependency on objectweb-asm to build with sisu 0.9.0.M4
* Tue Sep 24 2024 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * y2038.patch
    + Don't pass possibly negative time to File.setLastModified,
    where it is explicitly forbidden
    + Fixes java.lang.IllegalArgumentException: Negative time
* Thu Sep 19 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstrem version 4.10.0
  * New features and improvements
    + Change Snappy compressor to io.airlift:aircompressor
    + Fix modular jar final permissions
- Modified patch:
  * 0001-Remove-support-for-snappy.patch
    + rediff to changed context
* Thu Jun 13 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 4.9.2
  * New features and improvements
    + Allow copy all files without timestamp checking by
    DirectoryArchiver
    + Provide fluent setter for usingDefaultExcludes flag in
    AbstractFileSet
    + Upgrade many dependencies
- Modified patches:
  * 0001-Remove-support-for-snappy.patch
  * plexus-archiver-4.8.0-no_zstd.patch ->
    0002-Remove-support-for-zstd.patch
    + rediff to changed context
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 4.8.0
- Changes of 4.8.0
  * Security fix
    + Avoid override target symlink by standard file in
    AbstractUnArchiver (bsc#1215973, CVE-2023-37460)
  * New features and improvements
    + Add tzst alias for tar.zst archiver/unarchived (#274)
  * Bug Fixes
    + detect permissions for addFile (#293)
  * Maintenance
    + Remove public modifier from JUnit 5 tests (#294)
    + Use https in scm/url (#291)
    + Remove junit-jupiter-engine from project dependencies (#292)
    + Remove parent and reports menu from site (#282)
    + Cleanup after "veryLargeJar" test (#281)
    + Override project.url (#279)
- Changes of 4.7.1
  * Bug Fixes
    + don't apply umask on unknown perms (Win) (#273)
- Changes of 4.7.0
  * New features and improvements
    + add umask support and use 022 in RB mode (#271)
    + Use NIO Files for creating temporary files (#270)
    + Deprecate the JAR Index feature (JDK-8302819) (#268)
    + Add Archiver aliases for tar.* (#266)
  * Maintenance
    + Use JUnit TempDir to manage temporary files in tests (#269)
    + Override uId and gId for Tar in test (#264)
    + Bump maven-resources-plugin from 2.7 to 3.3.1 (#223)
- Changes of 4.6.3
  * New features and improvements
    + Fix path traversal vulnerability (#261)
    The vulnerability affects only directories whose name begins
    with the same prefix as the destination directory. For example
    malicious archive may extract file in /opt/directory instead
    of /opt/dir.
- Changes of 4.6.2
  * Bug Fixes
    + Fix regression in handling symbolic links. See
    codehaus-plexus/plexus-io#89
- Changes of 4.6.1
  * Bug Fixes
    + Normalize file separators before warning about equal archive
    entries (#249)
- Changes of 4.6.0
  * New features and improvements
    + keep file/directory permissions in Reproducible Builds
    mode (#241)
- Changes of 4.5.0
  * New features and improvements
    + Add zstd (un)archiver support (#226)
  * Bug Fixes
    + Fix UnArchiver#isOverwrite not working as expected (#229)
    Existing files were overridden only if UnArchiver#isOverwrite
    was set and the existing files were older than the archive
    entry.
    Now it works as documented: older files are always overridden;
    when UnArchiver#isOverwrite is true, existing files are always
    overridden regardless if they are older or not.
- Changes of 4.4.0
  * New features and improvements
    + Drop legacy plexus API and use only JSR330 components (#220)
- Changes of 4.3.0
  * New features and improvements
    + Require Java 8 (#206)
    + Refactor to use FileTime API (#199)
    + Rename setTime method to setZipEntryTime (#209)
    + Convert InputStreamSupplier to lambdas (#212)
  * Bug Fix
    + Reproducible Builds not working when using modular jar (#205)
- Changes of 4.2.7
  * New features and improvements
    + Respect order of META-INF/ and META-INF/MANIFEST.MF entries in
    a JAR file (#189)
- Changes of 4.2.6
  * New features and improvements
    + FileInputStream, FileOutputStream, FileReader and FileWriter
    are no longer used (#183)
    + Code cleanup (#172)
- Changes of 4.2.5
  * New features and improvements
    + Speed improvements (#157)
  * Bug Fixes
    + Fix use of a mismatching Unicode path extra field in zip
    unarchiving (#167)
    In some cases zip archiver may update the file path but not
    the Unicode path extra field. This would result in Plexus
    Archiver extracting the file using wrong (obsolete) path.
    Now Plexus Archiver follows the specification and in this
    case will ignore the extra filed and extract the file in the
    correct location.
- Changes of 4.2.4
  * Bug Fixes
    + Fix unjustified warning about casing for directory entries
    (#155)
- Changes of 4.2.2
  * Bug Fixes
    + DirectoryArchiver fails for symlinks if a parent directory
    doesn't exist (#131)
- Modified patch:
  * 0001-Remove-support-for-snappy.patch
    + rediff to changed context
- Removed patch:
  * logger-level.patch
    + not needed any more with this version
- Added patch:
  * plexus-archiver-4.8.0-no_zstd.patch
    + Remove support for ZStd compression to reduce the dependency
    graph
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not compile the test build against the legacy guava20 any more
* Sun Nov 24 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 4.2.1
- Modified patch:
  * 0001-Remove-support-for-snappy.patch
    + rediff to changed context
* Mon Apr  1 2019 Jan Engelhardt <jengelh@inai.de>
- Describe package, not the project vision.
* Fri Mar  8 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of plexus-archiver 3.6.0
- Generate and customize ant build file
- Make running of tests optional
- Added patches:
  * 0001-Remove-support-for-snappy.patch
    + When built without snappy support and trying to use Snappy,
    throw UnsupportedOperationException
  * logger-level.patch
    + Cast the result of getContainer() call, because the
    getLoggerManager() method is not a method of the
    PlexusContainer interface, but of the DefaultPlexusContainer
    implementation
